==> eiffelstudio-18.01.10.1424.tar: F_code/C14/ro653.c <==
/*
 * Code for class ROUTINE [G#1]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ro653.h"
#include "eif_built_in.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ROUTINE}.operands */
EIF_REFERENCE F941_7595 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {ROUTINE}.hash_code */
EIF_INTEGER_32 F941_7597 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER tp1;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tp1 = *(EIF_POINTER *)(Current + O6239[dtype-940]);
	Result = (EIF_INTEGER_32) (0x7FFFFFFF & (EIF_INTEGER_32) ((rt_int_ptr) (tp1)));
	ti4_1 = *(EIF_INTEGER_32 *)(Current + O6243[dtype-940]);
	ti4_1 = (EIF_INTEGER_32) (0x7FFFFFFF & (EIF_INTEGER_32) ((rt_int_ptr) (ti4_1)));
	Result = eif_bit_xor(Result,ti4_1);
	RTLE;
	return Result;
}

/* {ROUTINE}.is_equal */
EIF_BOOLEAN F941_7602 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_POINTER tp1;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	EIF_BOOLEAN tb6;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tb3 = '\0';
	tb4 = '\0';
	tb5 = '\0';
	tb6 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if (RTEQ(*(EIF_REFERENCE *)(Current + _REFACS_1_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb6 = RTEQ(*(EIF_REFERENCE *)(Current), tr1);
	}
	if (tb6) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		tb5 = RTEQ(*(EIF_REFERENCE *)(Current + _REFACS_2_), tr1);
	}
	if (tb5) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O6239[Dtype(arg1)-940]);
		tb4 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O6239[dtype-940]) == tp1);
	}
	if (tb4) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O6243[Dtype(arg1)-940]);
		tb3 = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O6243[dtype-940]) == ti4_1);
	}
	if (tb3) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O6245[Dtype(arg1)-940]);
		tb2 = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O6245[dtype-940]) == ti4_1);
	}
	if (tb2) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O6242[Dtype(arg1)-940]);
		tb1 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O6242[dtype-940]) == tp1);
	}
	if (tb1) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O6240[Dtype(arg1)-940]);
		Result = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O6240[dtype-940]) == tp1);
	}
	RTLE;
	return Result;
}

/* {ROUTINE}.valid_operands */
EIF_BOOLEAN F941_7603 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_NATURAL_8 tu1_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,loc3);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 == NULL)) {
		ti4_1 = *(EIF_INTEGER_32 *)(Current + O6231[dtype-940]);
		Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
	} else {
		ti4_1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (arg1);
		if ((EIF_BOOLEAN) (ti4_1 >= *(EIF_INTEGER_32 *)(Current + O6231[dtype-940]))) {
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
			loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
			for (;;) {
				if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current + O6231[dtype-940])) || (EIF_BOOLEAN) !Result)) break;
				tu1_1 = (EIF_NATURAL_8) eif_builtin_TUPLE_item_code (arg1, loc1);
				loc2 = (EIF_INTEGER_32) tu1_1;
				loc4 = F941_7627(Current, loc1);
				switch (loc2) {
					case 1L:
						tr1 = RTLNTY2(eif_new_type(906, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 2L:
						tr1 = RTLNTY2(eif_new_type(903, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 14L:
						tr1 = RTLNTY2(eif_new_type(900, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 6L:
						tr1 = RTLNTY2(eif_new_type(879, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 7L:
						tr1 = RTLNTY2(eif_new_type(876, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 8L:
						tr1 = RTLNTY2(eif_new_type(873, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 9L:
						tr1 = RTLNTY2(eif_new_type(870, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 10L:
						tr1 = RTLNTY2(eif_new_type(891, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 11L:
						tr1 = RTLNTY2(eif_new_type(888, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 12L:
						tr1 = RTLNTY2(eif_new_type(885, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 13L:
						tr1 = RTLNTY2(eif_new_type(882, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 5L:
						tr1 = RTLNTY2(eif_new_type(939, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 4L:
						tr1 = RTLNTY2(eif_new_type(894, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 3L:
						tr1 = RTLNTY2(eif_new_type(897, 0x00), 0x00);
						ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(loc4 == ti4_1);
						break;
					case 0L:
						loc3 = F868_6468(RTCW(arg1), loc1);
						if (F439_3895(Current, loc4)) {
							Result = '\0';
							if ((EIF_BOOLEAN)(loc3 != NULL)) {
								tr1 = RTCCL(loc3);
								ti4_1 = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_dynamic_type (tr1);
								Result = F439_3885(Current, ti4_1, loc4);
							}
						} else {
							Result = '\01';
							if (!(EIF_BOOLEAN)(loc3 == NULL)) {
								tr1 = RTCCL(loc3);
								ti4_1 = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_dynamic_type (tr1);
								Result = F439_3885(Current, ti4_1, loc4);
							}
						}
						break;
					default:
						Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
						break;
				}
				loc1++;
			}
		}
	}
	if ((EIF_BOOLEAN) (Result && (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current + O6230[dtype-940]))) {
		Result = '\0';
		tb1 = '\0';
		if ((EIF_BOOLEAN)(arg1 != NULL)) {
			tb2 = F868_6500(RTCW(arg1));
			tb1 = (EIF_BOOLEAN) !tb2;
		}
		if (tb1) {
			tr1 = F868_6468(RTCW(arg1), ((EIF_INTEGER_32) 1L));
			Result = (EIF_BOOLEAN)(tr1 != NULL);
		}
	}
	RTLE;
	return Result;
}

/* {ROUTINE}.copy */
void F941_7609 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != Current)) {
		eif_builtin_ANY_standard_copy (Current, arg1);
		tr1 = *(EIF_REFERENCE *)(Current);
		loc1 = tr1;
		if (EIF_TEST(loc1)) {
			tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (loc1);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
	}
	RTLE;
}

/* {ROUTINE}.flexible_call */
void F941_7612 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	RTCFDT;
	RTCDT;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,loc1);
	RTLR(2,Current);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLIU(5);
	
	RTGC;
	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(arg1 != NULL)) {
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6234[dtype-941])(Current, loc1);
	} else {
		RTCT0("from_precondition", EX_CHECK);
		tr1 = RTLNTY2(eif_gen_param(dftype, 1), 0x00);
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5514[Dtype(tr1)-821])(tr1);
		tr1 = F439_3890(Current, ti4_1, arg1);
		loc2 = tr1;
		loc2 = RTRV(eif_gen_param(dftype, 1),loc2);
		if (EIF_TEST(loc2)) {
			RTCK0;
		} else {
			RTCF0;
		}
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R6234[dtype-941])(Current, loc2);
	}
	RTLE;
}

/* {ROUTINE}.correct_mismatch */
void F941_7613 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {ROUTINE}.closed_operands */
EIF_REFERENCE F941_7614 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {ROUTINE}.closed_count */
EIF_INTEGER_32 F941_7615 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		ti4_1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (loc1);
		RTLE;
		return (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
	return (EIF_INTEGER_32) 0;
}

/* {ROUTINE}.open_map */
EIF_REFERENCE F941_7618 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {ROUTINE}.set_rout_disp */
void F941_7623 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_POINTER arg3, EIF_INTEGER_32 arg4, EIF_REFERENCE arg5, EIF_BOOLEAN arg6, EIF_BOOLEAN arg7, EIF_INTEGER_32 arg8, EIF_REFERENCE arg9, EIF_INTEGER_32 arg10)
{
	GTCX
	
	
	F941_7625(Current, arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9, arg10);
}

/* {ROUTINE}.set_rout_disp_final */
void F941_7624 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_POINTER arg3, EIF_REFERENCE arg4, EIF_BOOLEAN arg5, EIF_INTEGER_32 arg6)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg4);
	RTLIU(2);
	
	RTGC;
	*(EIF_POINTER *)(Current + O6239[dtype-940]) = (EIF_POINTER) arg1;
	*(EIF_POINTER *)(Current + O6242[dtype-940]) = (EIF_POINTER) arg2;
	*(EIF_POINTER *)(Current + O6240[dtype-940]) = (EIF_POINTER) arg3;
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg4;
	*(EIF_BOOLEAN *)(Current + O6230[dtype-940]) = (EIF_BOOLEAN) arg5;
	*(EIF_INTEGER_32 *)(Current + O6231[dtype-940]) = (EIF_INTEGER_32) arg6;
	RTLE;
}

/* {ROUTINE}.set_rout_disp_int */
void F941_7625 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_POINTER arg3, EIF_INTEGER_32 arg4, EIF_REFERENCE arg5, EIF_BOOLEAN arg6, EIF_BOOLEAN arg7, EIF_INTEGER_32 arg8, EIF_REFERENCE arg9, EIF_INTEGER_32 arg10)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg5);
	RTLR(2,arg9);
	RTLIU(3);
	
	RTGC;
	*(EIF_POINTER *)(Current + O6239[dtype-940]) = (EIF_POINTER) arg1;
	*(EIF_POINTER *)(Current + O6242[dtype-940]) = (EIF_POINTER) arg2;
	*(EIF_POINTER *)(Current + O6240[dtype-940]) = (EIF_POINTER) arg3;
	*(EIF_INTEGER_32 *)(Current + O6243[dtype-940]) = (EIF_INTEGER_32) arg4;
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg5;
	*(EIF_BOOLEAN *)(Current + O6244[dtype-940]) = (EIF_BOOLEAN) arg6;
	*(EIF_BOOLEAN *)(Current + O6230[dtype-940]) = (EIF_BOOLEAN) arg7;
	*(EIF_INTEGER_32 *)(Current + O6245[dtype-940]) = (EIF_INTEGER_32) arg8;
	RTAR(Current, arg9);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg9;
	*(EIF_INTEGER_32 *)(Current + O6231[dtype-940]) = (EIF_INTEGER_32) arg10;
	RTLE;
}

/* {ROUTINE}.open_types */
EIF_REFERENCE F941_7626 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {ROUTINE}.open_operand_type */
EIF_INTEGER_32 F941_7627 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTCFDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		{
			static EIF_TYPE_INDEX typarr0[] = {602,873,0xFFFF};
			EIF_TYPE typres0;
			static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
			
			typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
			tr1 = RTLNSMART(typres0.id);
		}
		ti4_1 = *(EIF_INTEGER_32 *)(Current + O6231[Dtype(Current)-940]);
		F603_4455(RTCW(tr1), ((EIF_INTEGER_32) -1L), ((EIF_INTEGER_32) 1L), ti4_1);
		loc1 = (EIF_REFERENCE) tr1;
		RTAR(Current, loc1);
		*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) loc1;
	}
	Result = F603_4460(RTCW(loc1), arg1);
	if ((EIF_BOOLEAN)(Result == ((EIF_INTEGER_32) -1L))) {
		tr1 = RTLNTY2(eif_gen_param(dftype, 1), 0x00);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R5513[Dtype(tr1)-821])(tr1, arg1);
		Result = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5514[Dtype(tr1)-821])(tr1);
		F603_4479(RTCW(loc1), Result, arg1);
	}
	RTLE;
	return Result;
}

void EIF_Minit653 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C14/ro653.c <==
/*
 * Code for class ROUTINE [G#1]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ro653.h"
#include "eif_built_in.h"
#include "eif_misc.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ROUTINE}.operands */
EIF_REFERENCE F1019_7904 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {ROUTINE}.hash_code */
EIF_INTEGER_32 F1019_7906 (EIF_REFERENCE Current)
{
	GTCX
	EIF_POINTER tp1;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tp1 = *(EIF_POINTER *)(Current + O5940[dtype-1018]);
	Result = (EIF_INTEGER_32) (0x7FFFFFFF & (EIF_INTEGER_32) ((rt_int_ptr) (tp1)));
	ti4_1 = *(EIF_INTEGER_32 *)(Current + O5944[dtype-1018]);
	ti4_1 = (EIF_INTEGER_32) (0x7FFFFFFF & (EIF_INTEGER_32) ((rt_int_ptr) (ti4_1)));
	Result = eif_bit_xor(Result,ti4_1);
	RTLE;
	return Result;
}

/* {ROUTINE}.is_equal */
EIF_BOOLEAN F1019_7911 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_POINTER tp1;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	EIF_BOOLEAN tb5;
	EIF_BOOLEAN tb6;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTCDT;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	Result = '\0';
	tb1 = '\0';
	tb2 = '\0';
	tb3 = '\0';
	tb4 = '\0';
	tb5 = '\0';
	tb6 = '\0';
	tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_);
	if (RTEQ(*(EIF_REFERENCE *)(Current + _REFACS_1_), tr1)) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
		tb6 = RTEQ(*(EIF_REFERENCE *)(Current), tr1);
	}
	if (tb6) {
		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_2_);
		tb5 = RTEQ(*(EIF_REFERENCE *)(Current + _REFACS_2_), tr1);
	}
	if (tb5) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O5940[Dtype(arg1)-1018]);
		tb4 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O5940[dtype-1018]) == tp1);
	}
	if (tb4) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O5944[Dtype(arg1)-1018]);
		tb3 = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O5944[dtype-1018]) == ti4_1);
	}
	if (tb3) {
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O5946[Dtype(arg1)-1018]);
		tb2 = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O5946[dtype-1018]) == ti4_1);
	}
	if (tb2) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O5943[Dtype(arg1)-1018]);
		tb1 = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O5943[dtype-1018]) == tp1);
	}
	if (tb1) {
		tp1 = *(EIF_POINTER *)(RTCW(arg1) + O5941[Dtype(arg1)-1018]);
		Result = (EIF_BOOLEAN)(*(EIF_POINTER *)(Current + O5941[dtype-1018]) == tp1);
	}
	RTLE;
	return Result;
}

/* {ROUTINE}.copy */
void F1019_7918 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(4);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(arg1 != Current)) {
		eif_builtin_ANY_standard_copy (Current, arg1);
		tr1 = *(EIF_REFERENCE *)(Current);
		loc1 = tr1;
		if (EIF_TEST(loc1)) {
			tr1 = F1_14(loc1);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
	}
	RTLE;
}

/* {ROUTINE}.correct_mismatch */
void F1019_7922 (EIF_REFERENCE Current)
{
	GTCX
	
	
	RTGC;
}

/* {ROUTINE}.closed_count */
EIF_INTEGER_32 F1019_7924 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 ti4_1;
	RTLD;
	
	RTLI(2);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		ti4_1 = (EIF_INTEGER_32) eif_builtin_TUPLE_count (loc1);
		RTLE;
		return (EIF_INTEGER_32) ti4_1;
	}
	RTLE;
	return (EIF_INTEGER_32) 0;
}

/* {ROUTINE}.set_rout_disp_final */
void F1019_7933 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_POINTER arg3, EIF_REFERENCE arg4, EIF_BOOLEAN arg5, EIF_INTEGER_32 arg6)
{
	GTCX
	RTCDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg4);
	RTLIU(2);
	
	RTGC;
	*(EIF_POINTER *)(Current + O5940[dtype-1018]) = (EIF_POINTER) arg1;
	*(EIF_POINTER *)(Current + O5943[dtype-1018]) = (EIF_POINTER) arg2;
	*(EIF_POINTER *)(Current + O5941[dtype-1018]) = (EIF_POINTER) arg3;
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg4;
	*(EIF_BOOLEAN *)(Current + O5931[dtype-1018]) = (EIF_BOOLEAN) arg5;
	*(EIF_INTEGER_32 *)(Current + O5932[dtype-1018]) = (EIF_INTEGER_32) arg6;
	RTLE;
}

void EIF_Minit653 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
